# Flot Examples

Here are some examples for Flot, the Javascript charting library for jQuery:

- Basic example
- Different graph types
- Setting various options and annotating a chart
- Updating graphs with AJAX and real-time updates

Being interactive:

- Turning series on/off
- Rectangular selection support and zooming and zooming with overview (both with selection plugin)
- Interacting with the data points
- Panning and zooming (with navigation plugin)
- Automatically redraw when window is resized (with resize plugin)

Various features:

- Using other symbols than circles for points (with symbol plugin)
- Plotting time series and visitors per day with zooming and weekends (with selection plugin)
- Multiple axes and interacting with the axes
- Thresholding the data (with threshold plugin)
- Stacked charts (with stacking plugin)
- Using filled areas to plot percentiles (with fillbetween plugin)
- Tracking curves with crosshair (with crosshair plugin)
- Plotting prerendered images (with image plugin)
- Pie charts (with pie plugin)